#!/usr/local/bin/python
# -*- coding:utf-8 -*-
"""    
Created on 2016-7-2
@author: WeiYanfeng

    P2PLayout 模式演示用的参数配置，由 CHubCallbackP2PLayout.py 使用。
"""

gDictP2PLayoutByPairId = {
    # P2PLayout sPairId配置参数
    # 以 sPairId 为键值，内容是 sSuffix = sPassword 组成的键值对
    '@sPairId': {
        '@sSuffix': '@sPassword',
    },
    'one': {
        'A': 'onePairA',
        'B': 'onePairB',
        'C': 'onePairC',
        'D': 'onePairD',
        'Test': 'onePairTest',
    },
}
